Index: wp-includes/post.php
===================================================================
--- wp-includes/post.php	(revision 15310)
+++ wp-includes/post.php	(working copy)
@@ -1008,16 +1008,20 @@
  *
  * @since 3.0.0
  * @param string $post_type The post type for which to remove the feature
  * @param string $feature The feature being removed
  */
 function remove_post_type_support( $post_type, $feature ) {
 	global $_wp_post_type_features;
 
 	if ( !isset($_wp_post_type_features[$post_type]) )
 		return;
+		
+	$features = (array) $feature;
 
-	if ( isset($_wp_post_type_features[$post_type][$feature]) )
-		unset($_wp_post_type_features[$post_type][$feature]);
+	foreach ($features as $feature) {
+		if ( isset($_wp_post_type_features[$post_type][$feature]) )
+			unset($_wp_post_type_features[$post_type][$feature]);
+	}
 }
 
 /**
@@ -1008,16 +1008,20 @@
  * @since 3.0.0
  * @param string $post_type The post type for which to remove the feature
- * @param string $feature The feature being removed
+ * @param string|array $feature The feature being removed, can be an array of feature strings or a single string
  */
 function remove_post_type_support( $post_type, $feature ) {
